@@ -42,10 +42,11 @@ extern crate serde_json;
 #[macro_use]
 extern crate trackable;
 
-pub use buf::{DecodeBuf, EncodeBuf};
+pub use byte_count::ByteCount;
 pub use chain::{StartDecoderChain, StartEncoderChain};
-pub use decode::{Decode, DecodeExt, DecodedValue};
+pub use decode::{Decode, DecodeExt};
 pub use encode::{Encode, EncodeExt, ExactBytesEncode};
+pub use eos::Eos;
 pub use error::{Error, ErrorKind};
 
 #[cfg(feature = "bincode_codec")]
@@ -57,11 +58,13 @@ pub mod fixnum;
 pub mod json_codec;
 pub mod io;
 pub mod monolithic;
+pub mod value;
 
-mod buf;
+mod byte_count;
 mod chain;
 mod decode;
 mod encode;
+mod eos;
 mod error;
 
 /// This crate specific `Result` type.
